@@ -31,6 +31,9 @@ GetProteinInteractions <- function(ProteinAccList , directorypath = NULL)
   ProteinInfoParsed_total = data.frame()
   baseUrl <- "http://www.uniprot.org/uniprot/"
   Colnames = "comment(SUBUNIT),interactor"
+  
+  message("Please wait we are processing your accessions ...")
+  pb <- progress::progress_bar$new(total = length(ProteinAccList))
   for (ProteinAcc in ProteinAccList)
   {
     #to see if Request == 200 or not
@@ -66,6 +69,8 @@ GetProteinInteractions <- function(ProteinAccList , directorypath = NULL)
     }else {
       HandleBadRequests(Request$status_code)
     }
+    pb$tick()
+    
   }
   if(!is.null(directorypath))
   {
